##  Configuring Role-Based Permissions
To configure role-based permissions unrelated to fact sheets, follow these steps:
  1. In the administration area, navigate to the User Roles and Permissions section.
  2. Select a role for which you want to configure permissions.
  3. On the role editing page, navigate to the Permissions tab.
  4. Adjust permissions as needed using relevant checkboxes.
  5. Save the changes.
![Adjusting Non-Fact-Sheet Permissions for the Viewer Role](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio274d0c5a7a4410148c49c83a28791f66_LowRes.png)
Adjusting Permissions Unrelated to Fact Sheets for the Viewer Role


YesNo
Send
